/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RenameConfigFileCommand.as 9121 2011-10-10 12:38:53Z durieuxp $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.monitoring.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.collections.ArrayCollection;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.jasmine.monitoring.eos.common.controls.ServerSideException;
import org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent;

import org.ow2.jasmine.monitoring.eos.monitoring.event.MonitoringEvent;
import org.ow2.jasmine.monitoring.eos.monitoring.model.MonitoringModelLocator;
import org.ow2.jasmine.monitoring.eos.monitoring.vo.ConfigFile;

/**
 * @author Philippe Durieux
 */
[Event(name="serverSideException", type="org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent")]
public class RenameConfigFileCommand implements ICommand, IResponder {
    private var model:MonitoringModelLocator = Monitoring.getInstance().getModel();
    private var dispatcher:CairngormEventDispatcher = Monitoring.getInstance().getDispatcher();

    public function RenameConfigFileCommand():void {
    }

    /**
     * Send the event to the java side, using the business layer of the pattern
     */
    public function execute(event:CairngormEvent):void {
        var ev:MonitoringEvent = (event as MonitoringEvent);
        model.getDelegate().responder = this;
        model.getDelegate().renameConfigFile(ev.configFile, ev.loadFile);
    }

    /**
     * Get the result of the java side. this method is called on each event from
     * Java.
     */
    public function result(event:Object):void {
        var files:ArrayCollection = (((event as ResultEvent).result) as ArrayCollection);
        var tmp:ArrayCollection = new ArrayCollection();
        model.configFiles = tmp; // force rewriting ?
        if (files != null) {
            for each (var f:ConfigFile in files) {
                tmp.addItem(f);
            }
            model.configFiles = tmp;
        }
    }

    /**
     * Handle fault messages
     */
    public function fault(info:Object):void {
        // Retrieve the fault event
        var faultEvent:FaultEvent = FaultEvent(info);

        // Tell the view and let it handle this
        var exc:ServerSideException = new ServerSideException("Error while renaming config file", "The operation could not be performed." + "\n" + faultEvent.fault.faultCode + "\n" + faultEvent.fault.faultString, faultEvent.fault.getStackTrace());
        var event:ServerSideExceptionEvent = new ServerSideExceptionEvent("serverSideException", exc);
        dispatcher.dispatchEvent(event);
    }

}
}
