/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JasmineEventNotificationVO.as 9121 2011-10-10 12:38:53Z durieuxp $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.monitoring.vo {

import avmplus.variableXml;

import com.adobe.cairngorm.vo.IValueObject;
import mx.collections.ArrayCollection;

/**
 * The ejb JasmineEventNotification is translated to actionscript
 * via the object JasmineEventNotificationVO.
 * @author durieuxp
 */
[Bindable]
public class JasmineEventNotificationVO implements IValueObject {
                 
    private var _id:String;

    private var _level:String;
    
    [Transient]
    private var _levelValue:int;
    public static const ERROR:int = 3;
    public static const WARN:int = 2;
    public static const INFO:int = 1;

    private var _date:Date;

    private var _message:String;

    private var _status:Boolean;

    private var _rule:String;

    private var _details:ArrayCollection;


    public function JasmineEventNotificationVO() {
    }


    public function get id():String {
        return _id;
    }

    public function set id(value:String):void {
        _id = value;
    }

    public function get level():String {
        return _level;
    }

    public function set level(value:String):void {
        _level = value;
        if (value.charAt(0) == 'E' || value.charAt(0) == 'e') {
             _levelValue = ERROR;
        } else if (value.charAt(0) == 'W' || value.charAt(0) == 'w') {
             _levelValue = WARN;
        } else {
            _levelValue = INFO;
        }
    }

    public function get levelValue():int {
        return _levelValue;
    }

    public function get date():Date {
        return _date;
    }

    public function set date(value:Date):void {
        _date = value;
    }

    public function get message():String {
        return _message;
    }

    public function set message(value:String):void {
        _message = value;
    }

    public function get status():Boolean {
        return _status;
    }

    public function set status(value:Boolean):void {
        _status = value;
    }

    public function get rule():String {
        return _rule;
    }

    public function set rule(value:String):void {
        _rule = value;
    }

    public function get details():ArrayCollection {
        return _details;
    }

    public function set details(value:ArrayCollection):void {
        _details = value;
    }

    /**
     * Check if the details contain the property, and return its value if yes, N/A otherwise
     *
     * @param searchedLabel The property to get the message of.
     * @return The value of the property, N/A otherwise.
     */
    public function hasDetail(searchedLabel:String):String {
        for each (var detail:JasmineEventNotificationDetailVO in this._details) {
            if (detail.label == searchedLabel) {
                return detail.message;
            }
        }
        return "N/A";
    }


}
}
